@@ -29,12 +29,17 @@ fn main() {
 
     let client_one = BasicClient::new(1);
     let client_two = BasicClient::new(2);
+    let client_three = BasicClient::new(3);
 
     let channel_a = "Channel A";
     let channel_b = "Channel B";
+    let channel_c = "Channel C";
+
+    let all_channels = "Channel *";
 
     pubsub.add_client(client_one);
     pubsub.add_client(client_two);
+    pubsub.add_client(client_three);
 
     if let Result::Err(unexpected_error) = pubsub.sub_client(client_one, channel_a) {
         println!("This should not happen: {}", unexpected_error);
@@ -48,19 +53,39 @@ fn main() {
         println!("This should not happen: {}", unexpected_error);
     }
 
-    pubsub.pub_message(channel_a, "Both clients should receive this message.");
-    pubsub.pub_message(channel_b, "Only Client 1 should receive this message.");
+    if let Result::Err(unexpected_error) = pubsub.sub_client(client_three, all_channels) {
+        println!("This should not happen: {}", unexpected_error);
+    }
+
+    println!("");
+    println!("Sending a message to Channel A");
+    pubsub.pub_message(channel_a, "All clients should receive this message.");
+
+    println!("");
+    println!("Sending a message to Channel B");
+    pubsub.pub_message(channel_b, "Clients 1 and 3 should receive this message.");
 
     if let Result::Err(unexpected_error) = pubsub.unsub_client(client_one, channel_a) {
         println!("This should not happen: {}", unexpected_error);
     }
 
-    pubsub.pub_message(channel_a, "Only Client 2 should receive this message.");
+    println!("");
+    println!("Sending a message to Channel A");
+    pubsub.pub_message(channel_a, "Clients 2 and 3 should receive this message.");
 
     pubsub.remove_client(client_one);
+    pubsub.remove_client(client_two);
 
-    pubsub.pub_message(channel_a, "Nobody should receive this message.");
+    println!("");
+    println!("Sending a message to Channel A");
+    pubsub.pub_message(channel_a, "Client 3 should receive this message.");
+    
+    println!("");
+    println!("Sending a message to Channel C");
+    pubsub.pub_message(channel_c, "Nobody ever subscribed to this channel, but Client 3 should receive it.");
 
+    println!("");
+    println!("Attempting to unsubscribe Client One after being removed.");
     if let Result::Err(expected_error) = pubsub.unsub_client(client_one, channel_a) {
         match expected_error {
             PubSubError::ClientNotSubscribedError => println!("This error is expected: {}", expected_error),
